==> estateplat-common-1.2.4-20201120.075511-535-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/QltFwFdcqYzBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.QltFwFdcqYz;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class QltFwFdcqYzBdc extends QltFwFdcqYz {
    private String dfqllxdm;
    private String dfqllxmc;
    private String dfdjlxdm;
    private String dfdjlxmc;
    private String dfghytmc;
    private String dfghytdm;
    private String dffwxzdm;
    private String dffwxzmc;
    private String dffwjgdm;
    private String dffwjgmc;
    @XmlAttribute(
            name = "DFQLLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqllxdm() {
        return dfqllxdm;
    }

    public void setDfqllxdm(String dfqllxdm) {
        this.dfqllxdm = dfqllxdm;
    }
    @XmlAttribute(
            name = "DFQLLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqllxmc() {
        return dfqllxmc;
    }

    public void setDfqllxmc(String dfqllxmc) {
        this.dfqllxmc = dfqllxmc;
    }
    @XmlAttribute(
            name = "DFDJLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxdm() {
        return dfdjlxdm;
    }

    public void setDfdjlxdm(String dfdjlxdm) {
        this.dfdjlxdm = dfdjlxdm;
    }
    @XmlAttribute(
            name = "DFDJLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxmc() {
        return dfdjlxmc;
    }

    public void setDfdjlxmc(String dfdjlxmc) {
        this.dfdjlxmc = dfdjlxmc;
    }
    @XmlAttribute(
            name = "DFGHYTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfghytmc() {
        return dfghytmc;
    }

    public void setDfghytmc(String dfghytmc) {
        this.dfghytmc = dfghytmc;
    }
    @XmlAttribute(
            name = "DFFWXZDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwxzdm() {
        return dffwxzdm;
    }

    public void setDffwxzdm(String dffwxzdm) {
        this.dffwxzdm = dffwxzdm;
    }
    @XmlAttribute(
            name = "DFFWXZMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwxzmc() {
        return dffwxzmc;
    }

    public void setDffwxzmc(String dffwxznc) {
        this.dffwxzmc = dffwxznc;
    }
    @XmlAttribute(
            name = "DFFWJGDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwjgdm() {
        return dffwjgdm;
    }

    public void setDffwjgdm(String dffwjgdm) {
        this.dffwjgdm = dffwjgdm;
    }
    @XmlAttribute(
            name = "DFFWJGMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwjgmc() {
        return dffwjgmc;
    }

    public void setDffwjgmc(String dffwjgmc) {
        this.dffwjgmc = dffwjgmc;
    }

    @XmlAttribute(
            name = "DFGHYTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfghytdm() {
        return dfghytdm;
    }

    public void setDfghytdm(String dfghytdm) {
        this.dfghytdm = dfghytdm;
    }
}

==> estateplat-common-1.2.4-20210322.013845-676-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/QltFwFdcqYzBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.QltFwFdcqYz;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class QltFwFdcqYzBdc extends QltFwFdcqYz {
    private String dfqllxdm;
    private String dfqllxmc;
    private String dfdjlxdm;
    private String dfdjlxmc;
    private String dfghytmc;
    private String dfghytdm;
    private String dffwxzdm;
    private String dffwxzmc;
    private String dffwjgdm;
    private String dffwjgmc;
    @XmlAttribute(
            name = "DFQLLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqllxdm() {
        return dfqllxdm;
    }

    public void setDfqllxdm(String dfqllxdm) {
        this.dfqllxdm = dfqllxdm;
    }
    @XmlAttribute(
            name = "DFQLLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfqllxmc() {
        return dfqllxmc;
    }

    public void setDfqllxmc(String dfqllxmc) {
        this.dfqllxmc = dfqllxmc;
    }
    @XmlAttribute(
            name = "DFDJLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxdm() {
        return dfdjlxdm;
    }

    public void setDfdjlxdm(String dfdjlxdm) {
        this.dfdjlxdm = dfdjlxdm;
    }
    @XmlAttribute(
            name = "DFDJLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfdjlxmc() {
        return dfdjlxmc;
    }

    public void setDfdjlxmc(String dfdjlxmc) {
        this.dfdjlxmc = dfdjlxmc;
    }
    @XmlAttribute(
            name = "DFGHYTMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfghytmc() {
        return dfghytmc;
    }

    public void setDfghytmc(String dfghytmc) {
        this.dfghytmc = dfghytmc;
    }
    @XmlAttribute(
            name = "DFFWXZDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwxzdm() {
        return dffwxzdm;
    }

    public void setDffwxzdm(String dffwxzdm) {
        this.dffwxzdm = dffwxzdm;
    }
    @XmlAttribute(
            name = "DFFWXZMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwxzmc() {
        return dffwxzmc;
    }

    public void setDffwxzmc(String dffwxzmc) {
        this.dffwxzmc = dffwxzmc;
    }
    @XmlAttribute(
            name = "DFFWJGDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwjgdm() {
        return dffwjgdm;
    }

    public void setDffwjgdm(String dffwjgdm) {
        this.dffwjgdm = dffwjgdm;
    }
    @XmlAttribute(
            name = "DFFWJGMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffwjgmc() {
        return dffwjgmc;
    }

    public void setDffwjgmc(String dffwjgmc) {
        this.dffwjgmc = dffwjgmc;
    }

    @XmlAttribute(
            name = "DFGHYTDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfghytdm() {
        return dfghytdm;
    }

    public void setDfghytdm(String dfghytdm) {
        this.dfghytdm = dfghytdm;
    }
}
